@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2026 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -959,6 +959,7 @@ SCIP_RETCODE doHeurCreate(
    (*heur)->ncalls = 0;
    (*heur)->nsolsfound = 0;
    (*heur)->nbestsolsfound = 0;
+   (*heur)->exact = FALSE;
    (*heur)->initialized = FALSE;
    (*heur)->divesets = NULL;
    (*heur)->ndivesets = 0;
@@ -1212,15 +1213,15 @@ SCIP_Bool SCIPheurShouldBeExecuted(
        || ((heur->timingmask & SCIP_HEURTIMING_DURINGPRESOLLOOP) && heurtiming == SCIP_HEURTIMING_DURINGPRESOLLOOP) )
    {
       /* heuristic may be executed before/during presolving. Do so, if it was not disabled by setting the frequency to -1 */
-      execute = heur->freq >= 0; 
-   } 
+      execute = heur->freq >= 0;
+   }
    else if( (heur->timingmask & SCIP_HEURTIMING_AFTERPSEUDONODE) == 0
       && (heurtiming == SCIP_HEURTIMING_AFTERLPNODE || heurtiming == SCIP_HEURTIMING_AFTERLPPLUNGE) )
    {
       /* heuristic was skipped on intermediate pseudo nodes: check, if a node matching the execution frequency lies
        * between the current node and the last LP node of the path
        */
-      execute = (heur->freq > 0 && depth >= heur->freqofs 
+      execute = (heur->freq > 0 && depth >= heur->freqofs
          && ((depth + heur->freq - heur->freqofs) / heur->freq
             != (lpstateforkdepth + heur->freq - heur->freqofs) / heur->freq));
    }
@@ -1289,6 +1290,9 @@ SCIP_RETCODE SCIPheurExec(
 
    *result = SCIP_DIDNOTRUN;
 
+   if( set->exact_enable && !heur->exact )
+      return SCIP_OKAY;
+
    delayed = FALSE;
    execute = SCIPheurShouldBeExecuted(heur, depth, lpstateforkdepth, heurtiming, &delayed);
 
@@ -1324,7 +1328,7 @@ SCIP_RETCODE SCIPheurExec(
          && *result != SCIP_DELAYED
          && *result != SCIP_UNBOUNDED )
       {
-         SCIPerrorMessage("execution method of primal heuristic <%s> returned invalid result <%d>\n", 
+         SCIPerrorMessage("execution method of primal heuristic <%s> returned invalid result <%d>\n",
             heur->name, *result);
          return SCIP_INVALIDRESULT;
       }
@@ -1449,6 +1453,16 @@ void SCIPheurSetExitsol(
    heur->heurexitsol = heurexitsol;
 }
 
+/** marks the primal heuristic as safe to use in exact solving mode */
+void SCIPheurMarkExact(
+   SCIP_HEUR*            heur                /**< primal heuristic */
+   )
+{
+   assert(heur != NULL);
+
+   heur->exact = TRUE;
+}
+
 /** gets name of primal heuristic */
 const char* SCIPheurGetName(
    SCIP_HEUR*            heur                /**< primal heuristic */
@@ -1699,21 +1713,18 @@ SCIP_RETCODE SCIPvariablegraphBreadthFirst(
    )
 {
    SCIP_VAR** vars;
-
+   SCIP_VAR** varbuffer;
    int* queue;
-   int  nvars;
-   int i;
+   SCIP_Bool localvargraph;
+   int nvars;
+   int nbinintvars;
    int currlvlidx;
    int nextlvlidx;
    int increment = 1;
    int currentdistance;
    int nbinintvarshit;
    int nvarshit;
-   int nbinvars;
-   int nintvars;
-   int nbinintvars;
-   SCIP_VAR** varbuffer;
-   SCIP_Bool localvargraph;
+   int i;
 
    assert(scip != NULL);
    assert(startvars != NULL);
@@ -1722,12 +1733,14 @@ SCIP_RETCODE SCIPvariablegraphBreadthFirst(
    assert(maxdistance >= 0);
 
    /* get variable data */
-   SCIP_CALL( SCIPgetVarsData(scip, &vars, &nvars, &nbinvars, &nintvars, NULL, NULL) );
+   vars = SCIPgetVars(scip);
+   nvars = SCIPgetNVars(scip);
 
    if( nvars == 0 )
       return SCIP_OKAY;
 
-   nbinintvars = nbinvars + nintvars;
+   nbinintvars = nvars - SCIPgetNContVars(scip) - SCIPgetNContImplVars(scip);
+   assert(nbinintvars >= 0);
 
    SCIP_CALL( SCIPallocBufferArray(scip, &queue, nvars) );
    SCIP_CALL( SCIPallocClearBufferArray(scip, &varbuffer, nvars) );
