@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2026 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -1285,7 +1285,7 @@ SCIP_RETCODE determineBestBounds(
    for(i = 0; i < ncols; i++)
    {
       var = SCIPmatrixGetVar(matrix, i);
-      if( SCIPvarGetType(var) == SCIP_VARTYPE_CONTINUOUS || SCIPvarGetType(var) == SCIP_VARTYPE_IMPLINT )
+      if( !SCIPvarIsNonimpliedIntegral(var) )
       {
          colmap[i] = numberconvars; /* start numbering with 0 */
          numberconvars++;
@@ -1348,7 +1348,7 @@ SCIP_RETCODE determineBestBounds(
    for(i = 0; i < ncols; i++)
    {
       var = SCIPmatrixGetVar(matrix, i);
-      if( SCIPvarGetType(var) == SCIP_VARTYPE_CONTINUOUS || SCIPvarGetType(var) == SCIP_VARTYPE_IMPLINT )
+      if( !SCIPvarIsNonimpliedIntegral(var) )
       {
          SCIP_Real objval = SCIPvarGetObj(var);
          int cidx = colmap[i];
@@ -1632,8 +1632,8 @@ SCIP_RETCODE dualBoundStrengthening(
    {
       var = SCIPmatrixGetVar(matrix, i);
 
-      if( SCIPmatrixUplockConflict(matrix, i) || SCIPmatrixDownlockConflict(matrix, i) ||
-         (SCIPvarGetType(var) != SCIP_VARTYPE_CONTINUOUS && SCIPvarGetType(var) != SCIP_VARTYPE_IMPLINT) )
+      if( SCIPmatrixUplockConflict(matrix, i) || SCIPmatrixDownlockConflict(matrix, i)
+         || SCIPvarIsNonimpliedIntegral(var) )
       {
          /* we don't care about integral variables or variables that have conflicting locks */
          isubimplied[i] = FALSE;
@@ -1990,8 +1990,8 @@ SCIP_RETCODE dualBoundStrengthening(
 
       for( i = 0; i < nimplubvars; i++ )
       {
-         assert(SCIPvarGetType(SCIPmatrixGetVar(matrix, implubvars[i])) == SCIP_VARTYPE_CONTINUOUS ||
-            SCIPvarGetType(SCIPmatrixGetVar(matrix, implubvars[i])) == SCIP_VARTYPE_IMPLINT);
+         assert(!SCIPvarIsIntegral(SCIPmatrixGetVar(matrix, implubvars[i]))
+               || SCIPvarIsImpliedIntegral(SCIPmatrixGetVar(matrix, implubvars[i])));
          calcMinColActivity(scip, matrix, implubvars[i], lbdual, ubdual, mincolact, mincolactinf);
       }
 
@@ -2298,7 +2298,7 @@ SCIP_DECL_PRESOLEXEC(presolExecDualinfer)
          /* keep a small statistic which types of variables are fixed */
          if( fixed )
          {
-            if( SCIPvarGetType(var) == SCIP_VARTYPE_CONTINUOUS || SCIPvarGetType(var) == SCIP_VARTYPE_IMPLINT )
+            if( !SCIPvarIsNonimpliedIntegral(var) )
                nconvarsfixed++;
             else if( SCIPvarGetType(var) == SCIP_VARTYPE_BINARY )
                nbinvarsfixed++;
